# API Reference

Auto-generated documentation from source code.

## Client

- [QGendaClient / AsyncQGendaClient](client.md)

## Resources

- [Schedule](resources/schedule.md)
- [Staff](resources/staff.md)
- [Task](resources/task.md)
- [Facility](resources/facility.md)
- [Organization](resources/organization.md)
- [Time Event](resources/time_event.md)
- [Daily Case](resources/daily_case.md)
- [Request](resources/request.md)
- [Request Limit](resources/request_limit.md)
- [Daily](resources/daily.md)
- [Company](resources/company.md)
- [Tag](resources/tag.md)
- [Profile](resources/profile.md)
- [Pay](resources/pay.md)
- [Staff Target](resources/staff_target.md)
- [Credit](resources/credit.md)
- [Notification](resources/notification.md)
- [User](resources/user.md)
- [Integration](resources/integration.md)
- [Credentialing](resources/credentialing.md)
- [Support](resources/support.md)

## Core

- [Configuration](config.md)
- [OData](odata.md)
- [Response](response.md)
- [Exceptions](exceptions.md)
- [Compat](compat.md)
